{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Merge, annotate, and generate a TSV for SVs",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/blocklist_bedpe"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/cohort_name"
                },
                {
                    "type": "boolean",
                    "id": "#main/estimate_sv_distance"
                },
                {
                    "type": "string",
                    "id": "#main/genome_build"
                },
                {
                    "type": "int",
                    "id": "#main/max_distance_to_merge"
                },
                {
                    "type": "int",
                    "id": "#main/minimum_sv_calls"
                },
                {
                    "type": "int",
                    "id": "#main/minimum_sv_size"
                },
                {
                    "type": "boolean",
                    "id": "#main/same_strand"
                },
                {
                    "type": "boolean",
                    "id": "#main/same_type"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/snps_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/sv_vcfs"
                }
            ],
            "steps": [
                {
                    "run": "#annotsv.cwl",
                    "in": [
                        {
                            "source": "#main/genome_build",
                            "id": "#main/bcftools_annotate_variants/genome_build"
                        },
                        {
                            "source": "#main/filter_blocklist_bcftools/filtered_sv_vcf",
                            "id": "#main/bcftools_annotate_variants/input_vcf"
                        },
                        {
                            "default": "bcftools-merged-AnnotSV.tsv",
                            "id": "#main/bcftools_annotate_variants/output_tsv_name"
                        },
                        {
                            "source": [
                                "#main/snps_vcf"
                            ],
                            "valueFrom": "${ return [ self ]; }",
                            "id": "#main/bcftools_annotate_variants/snps_vcf"
                        }
                    ],
                    "out": [
                        "#main/bcftools_annotate_variants/sv_variants_tsv"
                    ],
                    "id": "#main/bcftools_annotate_variants"
                },
                {
                    "run": "#annotsv_filter.cwl",
                    "in": [
                        {
                            "source": "#main/bcftools_annotate_variants/sv_variants_tsv",
                            "id": "#main/bcftools_annotsv_filter/annotsv_tsv"
                        },
                        {
                            "default": "0.05",
                            "id": "#main/bcftools_annotsv_filter/filtering_frequency"
                        }
                    ],
                    "out": [
                        "#main/bcftools_annotsv_filter/filtered_tsv"
                    ],
                    "id": "#main/bcftools_annotsv_filter"
                },
                {
                    "run": "#bcftools_merge.cwl",
                    "in": [
                        {
                            "default": "none",
                            "id": "#main/bcftools_merge_sv_vcfs/merge_method"
                        },
                        {
                            "default": "v",
                            "id": "#main/bcftools_merge_sv_vcfs/output_type"
                        },
                        {
                            "default": "bcftools-sv-merged.vcf",
                            "id": "#main/bcftools_merge_sv_vcfs/output_vcf_name"
                        },
                        {
                            "source": "#main/sv_vcfs",
                            "id": "#main/bcftools_merge_sv_vcfs/vcfs"
                        }
                    ],
                    "out": [
                        "#main/bcftools_merge_sv_vcfs/merged_sv_vcf"
                    ],
                    "id": "#main/bcftools_merge_sv_vcfs"
                },
                {
                    "run": "#filter_sv_vcf_blocklist_bedpe.cwl",
                    "in": [
                        {
                            "source": "#main/blocklist_bedpe",
                            "id": "#main/filter_blocklist_bcftools/blocklist_bedpe"
                        },
                        {
                            "source": "#main/bcftools_merge_sv_vcfs/merged_sv_vcf",
                            "id": "#main/filter_blocklist_bcftools/input_vcf"
                        },
                        {
                            "default": "bcftools-sv-merged",
                            "id": "#main/filter_blocklist_bcftools/output_vcf_basename"
                        }
                    ],
                    "out": [
                        "#main/filter_blocklist_bcftools/filtered_sv_vcf"
                    ],
                    "id": "#main/filter_blocklist_bcftools"
                },
                {
                    "run": "#filter_sv_vcf_blocklist_bedpe.cwl",
                    "in": [
                        {
                            "source": "#main/blocklist_bedpe",
                            "id": "#main/filter_blocklist_survivor/blocklist_bedpe"
                        },
                        {
                            "source": "#main/survivor_merge_sv_vcfs/merged_vcf",
                            "id": "#main/filter_blocklist_survivor/input_vcf"
                        },
                        {
                            "default": "SURVIVOR-sv-merged",
                            "id": "#main/filter_blocklist_survivor/output_vcf_basename"
                        }
                    ],
                    "out": [
                        "#main/filter_blocklist_survivor/filtered_sv_vcf"
                    ],
                    "id": "#main/filter_blocklist_survivor"
                },
                {
                    "run": "#annotsv.cwl",
                    "in": [
                        {
                            "source": "#main/genome_build",
                            "id": "#main/survivor_annotate_variants/genome_build"
                        },
                        {
                            "source": "#main/filter_blocklist_survivor/filtered_sv_vcf",
                            "id": "#main/survivor_annotate_variants/input_vcf"
                        },
                        {
                            "default": "SURVIVOR-merged-AnnotSV.tsv",
                            "id": "#main/survivor_annotate_variants/output_tsv_name"
                        },
                        {
                            "source": [
                                "#main/snps_vcf"
                            ],
                            "valueFrom": "${ return [ self ]; }",
                            "id": "#main/survivor_annotate_variants/snps_vcf"
                        }
                    ],
                    "out": [
                        "#main/survivor_annotate_variants/sv_variants_tsv"
                    ],
                    "id": "#main/survivor_annotate_variants"
                },
                {
                    "run": "#survivor.cwl",
                    "in": [
                        {
                            "default": "SURVIVOR-sv-merged.vcf",
                            "id": "#main/survivor_merge_sv_vcfs/cohort_name"
                        },
                        {
                            "source": "#main/estimate_sv_distance",
                            "id": "#main/survivor_merge_sv_vcfs/estimate_sv_distance"
                        },
                        {
                            "source": "#main/max_distance_to_merge",
                            "id": "#main/survivor_merge_sv_vcfs/max_distance_to_merge"
                        },
                        {
                            "source": "#main/minimum_sv_calls",
                            "id": "#main/survivor_merge_sv_vcfs/minimum_sv_calls"
                        },
                        {
                            "source": "#main/minimum_sv_size",
                            "id": "#main/survivor_merge_sv_vcfs/minimum_sv_size"
                        },
                        {
                            "source": "#main/same_strand",
                            "id": "#main/survivor_merge_sv_vcfs/same_strand"
                        },
                        {
                            "source": "#main/same_type",
                            "id": "#main/survivor_merge_sv_vcfs/same_type"
                        },
                        {
                            "source": "#main/sv_vcfs",
                            "id": "#main/survivor_merge_sv_vcfs/vcfs"
                        }
                    ],
                    "out": [
                        "#main/survivor_merge_sv_vcfs/merged_vcf"
                    ],
                    "id": "#main/survivor_merge_sv_vcfs"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/bcftools_annotate_variants/sv_variants_tsv",
                    "id": "#main/bcftools_merged_annotated_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bcftools_annotsv_filter/filtered_tsv",
                    "id": "#main/bcftools_merged_filtered_annotated_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/filter_blocklist_bcftools/filtered_sv_vcf",
                    "id": "#main/bcftools_merged_sv_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/survivor_annotate_variants/sv_variants_tsv",
                    "id": "#main/survivor_merged_annotated_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/filter_blocklist_survivor/filtered_sv_vcf",
                    "id": "#main/survivor_merged_sv_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "arguments": [
                "/opt/AnnotSV_2.1/bin/AnnotSV",
                "-bedtools",
                "/usr/bin/bedtools",
                "-outputDir",
                "$(runtime.outdir)"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/annotsv-cwl:2.1"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-genomeBuild"
                    },
                    "id": "#annotsv.cwl/genome_build"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-SVinputFile"
                    },
                    "doc": "vcf file to filter",
                    "id": "#annotsv.cwl/input_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "AnnotSV.tsv",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-outputFile"
                    },
                    "doc": "output file name",
                    "id": "#annotsv.cwl/output_tsv_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-vcfFiles",
                        "itemSeparator": ","
                    },
                    "doc": "snps vcf(s) for adding hom/het snp counts found within svs",
                    "id": "#annotsv.cwl/snps_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_tsv_name)"
                    },
                    "id": "#annotsv.cwl/sv_variants_tsv"
                }
            ],
            "id": "#annotsv.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter AnnotSV tsv output generated from a bcftools merged vcf",
            "baseCommand": [
                "python3",
                "AnnotSV_filter.py"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "python:3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "AnnotSV_filter.py",
                            "entry": "import argparse\nimport csv\nimport sys\n\nparser = argparse.ArgumentParser()\nparser.add_argument('--input', '-i', dest=\"input\", help='input AnnotSV tsv file', required=True, action=\"store\")\nparser.add_argument('--output', '-o', dest=\"output\", help='output tsv file name', required=True, action=\"store\")\nparser.add_argument('--filtering_frequency', dest=\"filtering_frequency\", help=\"frequency to filter with\", action=\"store\", type=float, default=\"0.05\")\nparser.add_argument('--all-CDS', dest=\"CDS\", help=\"Do not require a positive CoDing Sequence overlap\", action=\"store_true\")\nparser.add_argument('--ignore-pass-filter', dest=\"filter\", help=\"Do not require calls to have a PASS filter\", action=\"store_true\")\n\nargs = parser.parse_args()\ninput_file_name  = args.input\noutput_file_name = args.output\nfiltering_frequency = args.filtering_frequency\nall_cds = args.CDS\nignore_pass_filter = args.filter\n\nwith open(input_file_name, 'r') as file_in, open(output_file_name, 'w') as file_out:\n    file_in = csv.DictReader(file_in, delimiter='\\t')\n    file_out = csv.DictWriter(file_out, fieldnames=file_in.fieldnames, delimiter='\\t')\n    file_out.writeheader()\n    total_sv_count = 0\n    pass_sv_count = 0\n    for row in file_in:\n        total_sv_count += 1\n        if(row['AnnotSV type'] == 'split' \\\n            and (row['FILTER'] == 'PASS' or ignore_pass_filter) \\\n            and (int(row['CDS length']) > 0 or all_cds) \\\n            and float(row['IMH_AF']) < filtering_frequency\n            and float(row['1000g_max_AF']) < filtering_frequency\n            and not(float(row['DGV_LOSS_Frequency']) > filtering_frequency and 'DEL' in row['SV type']) \n            and not(float(row['DGV_GAIN_Frequency']) < filtering_frequency and ('DUP' in row['SV type'] or 'INS' in row['SV type']))\n            and not(('Manta' in row['ID'] and 'IMPRECISE' in row['INFO']) or (row['QUAL'] != '.' and 'IMPRECISE' in row['INFO'])) ):\n            file_out.writerow(row)\n            pass_sv_count += 1\n    print(\"total sv count:\",total_sv_count)\n    print(\"total sv passed count:\",pass_sv_count)\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--all-CDS"
                    },
                    "id": "#annotsv_filter.cwl/all_CDS"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--input"
                    },
                    "id": "#annotsv_filter.cwl/annotsv_tsv"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--filtering_frequency"
                    },
                    "id": "#annotsv_filter.cwl/filtering_frequency"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--ignore-pass-filter"
                    },
                    "id": "#annotsv_filter.cwl/ignore_pass_filter"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "filtered-bcftools-merged-AnnotSV.tsv",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--output"
                    },
                    "id": "#annotsv_filter.cwl/output_tsv_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_tsv_name)"
                    },
                    "id": "#annotsv_filter.cwl/filtered_tsv"
                }
            ],
            "id": "#annotsv_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/opt/bcftools/bin/bcftools",
                "merge"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.9"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--force-samples"
                    },
                    "doc": "resolve duplicate sample names",
                    "id": "#bcftools_merge.cwl/force_merge"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#bcftools_merge.cwl/merge_method/none",
                            "#bcftools_merge.cwl/merge_method/snps",
                            "#bcftools_merge.cwl/merge_method/indels",
                            "#bcftools_merge.cwl/merge_method/both",
                            "#bcftools_merge.cwl/merge_method/all",
                            "#bcftools_merge.cwl/merge_method/id"
                        ]
                    },
                    "default": "none",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--merge"
                    },
                    "doc": "method used to merge allow multiallelic indels/snps",
                    "id": "#bcftools_merge.cwl/merge_method"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--missing-to-ref"
                    },
                    "doc": "assume genotypes at missing sites are 0/0",
                    "id": "#bcftools_merge.cwl/missing_ref"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#bcftools_merge.cwl/output_type/b",
                            "#bcftools_merge.cwl/output_type/u",
                            "#bcftools_merge.cwl/output_type/z",
                            "#bcftools_merge.cwl/output_type/v"
                        ]
                    },
                    "default": "z",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--output-type"
                    },
                    "doc": "output file format",
                    "id": "#bcftools_merge.cwl/output_type"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "bcftools_merged.vcf.gz",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--output"
                    },
                    "doc": "output vcf file name",
                    "id": "#bcftools_merge.cwl/output_vcf_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "input bgzipped tabix indexed vcfs to merge",
                    "id": "#bcftools_merge.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_name)"
                    },
                    "id": "#bcftools_merge.cwl/merged_sv_vcf"
                }
            ],
            "id": "#bcftools_merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "filter_sv_vcf_blocklist_bedpe.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/basespace_chromoseq:v12"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "filter_sv_vcf_blocklist_bedpe.sh",
                            "entry": "#!/bin/bash\nset -eou pipefail\nset -o errexit\n\nif [[ \"$#\" == 4 ]];then # blocklist_bedpe is passed.\n    INPUT_VCF=\"$1\"\n    BL_BEDPE=\"$2\"\n    SLOPE=\"$3\"\n    OUT_BASE=\"$4\"\n\n    #CNVkit outputs invalid format like CIPOS=.,894;CIEND=.,894, which can cause svtools vcftobedpe fail\n    if [[ \"$INPUT_VCF\" =~ \\.vcf\\.gz$ ]]; then\n        /bin/zcat \"$INPUT_VCF\" | /bin/sed -E 's/CIPOS=\\.,[0-9]+;CIEND=\\.,[0-9]+/CIPOS=0,0;CIEND=0,0/g' > fixed_input.vcf\n    else\n        /bin/sed -E 's/CIPOS=\\.,[0-9]+;CIEND=\\.,[0-9]+/CIPOS=0,0;CIEND=0,0/g' \"$INPUT_VCF\" > fixed_input.vcf\n    fi\n    #svtools vcftobedpe can take either .vcf or .vcf.gz\n    /opt/conda/envs/python2/bin/svtools vcftobedpe -i fixed_input.vcf -o tmp.bedpe\n    /bin/grep '^#' tmp.bedpe > tmp.header\n    /usr/local/bin/bedtools pairtopair -is -slop \"$SLOPE\" -type notboth -a tmp.bedpe -b \"$BL_BEDPE\" | /bin/cat tmp.header /dev/stdin | /opt/conda/envs/python2/bin/svtools bedpetovcf -i /dev/stdin | /opt/conda/envs/python2/bin/svtools vcfsort /dev/stdin > \"$OUT_BASE.vcf\"\n\n    /opt/htslib/bin/bgzip $OUT_BASE.vcf\n   /usr/local/bin/tabix -p vcf $OUT_BASE.vcf.gz\nelse # blocklist_bedpe is not passed.\n    INPUT_VCF=\"$1\"\n    SLOPE=\"$2\"\n    OUT_BASE=\"$3\"\n\n    /usr/local/bin/bedtools sort -header -i \"$INPUT_VCF\" > $OUT_BASE.vcf\n    /opt/htslib/bin/bgzip $OUT_BASE.vcf\n    /usr/local/bin/tabix -p vcf $OUT_BASE.vcf.gz\nfi\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "blocklist bedpe file",
                    "id": "#filter_sv_vcf_blocklist_bedpe.cwl/blocklist_bedpe"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "vcf file to filter",
                    "id": "#filter_sv_vcf_blocklist_bedpe.cwl/input_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "blocklist_filtered",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "output vcf basename",
                    "id": "#filter_sv_vcf_blocklist_bedpe.cwl/output_vcf_basename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 100,
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "slope(bp) used in bedtools pairtopair",
                    "id": "#filter_sv_vcf_blocklist_bedpe.cwl/slope"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#filter_sv_vcf_blocklist_bedpe.cwl/filtered_sv_vcf"
                }
            ],
            "id": "#filter_sv_vcf_blocklist_bedpe.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Run SURVIVOR to merge SV calls",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/survivor_merge_helper.sh"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/survivor-cwl:1.0.6.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 2000,
                    "coresMin": 1
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8
                    },
                    "default": "SURVIVOR-sv-merged.vcf",
                    "doc": "Used to generate the output file name",
                    "id": "#survivor.cwl/cohort_name"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 6,
                        "valueFrom": "${\n  if(inputs.estimate_sv_distance){\n    return \"1\";\n  } else {\n    return \"0\";\n  }\n}\n"
                    },
                    "doc": "Estimate distance based on the size of SV",
                    "id": "#survivor.cwl/estimate_sv_distance"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Maximum distance of variants to consider for merging",
                    "id": "#survivor.cwl/max_distance_to_merge"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Minimum number of sv calls needed to be merged",
                    "id": "#survivor.cwl/minimum_sv_calls"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 7
                    },
                    "doc": "Minimum size of SVs to merge",
                    "id": "#survivor.cwl/minimum_sv_size"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "${\n  if(inputs.same_strand){\n    return \"1\";\n  } else {\n    return \"0\";\n  }\n}\n"
                    },
                    "doc": "Require merged SVs to be on the same strand",
                    "id": "#survivor.cwl/same_strand"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 4,
                        "valueFrom": "${\n  if(inputs.same_type){\n    return \"1\";\n  } else {\n    return \"0\";\n  }\n}\n"
                    },
                    "doc": "Require merged SVs to be of the same type",
                    "id": "#survivor.cwl/same_type"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1,
                        "itemSeparator": ","
                    },
                    "doc": "Array of VCFs to merge SV calls of",
                    "id": "#survivor.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cohort_name)"
                    },
                    "id": "#survivor.cwl/merged_vcf"
                }
            ],
            "id": "#survivor.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
